frccontrol
##########

Provides wrappers around Python Control for making development of state-space
models for the FIRST Robotics Competition easier.

Dependencies
************

- `Python 3.5 or newer <https://www.python.org/downloads/>`_
- Python Control

Installation
************

On Windows, execute::

    py -m pip install frccontrol

On Linux/OSX, execute::

    pip install frccontrol
